@@ -7,12 +7,16 @@ from linkplay.consts import (
     INPUT_MODE_MAP,
     LOGGER,
     PLAY_MODE_SEND_MAP,
+    AudioOutputHwMode,
+    AudioOutputModeResponse,
     ChannelType,
     DeviceAttribute,
     EqualizerMode,
     InputMode,
     LinkPlayCommand,
     LoopMode,
+    MetaInfo,
+    MetaInfoMetaData,
     MultiroomAttribute,
     MuteMode,
     PlayerAttribute,
@@ -128,6 +132,7 @@ class LinkPlayPlayer:
     bridge: LinkPlayBridge
     properties: dict[PlayerAttribute, str]
     custom_properties: dict[PlayerAttribute, str]
+    metainfo: dict[MetaInfo, dict[MetaInfoMetaData, str]]
 
     previous_playing_mode: PlayingMode | None = None
 
@@ -135,6 +140,7 @@ class LinkPlayPlayer:
         self.bridge = bridge
         self.properties = dict.fromkeys(PlayerAttribute.__members__.values(), "")
         self.custom_properties = dict.fromkeys(PlayerAttribute.__members__.values(), "")
+        self.metainfo = dict.fromkeys(MetaInfo.__members__.values(), {})
 
     def to_dict(self):
         """Return the state of the LinkPlayPlayer."""
@@ -147,6 +153,18 @@ class LinkPlayPlayer:
         )  # type: ignore[assignment]
 
         self.properties = fixup_player_properties(properties)
+        if self.bridge.device.manufacturer == MANUFACTURER_WIIM:
+            try:
+                self.metainfo: dict[
+                    MetaInfo, dict[MetaInfoMetaData, str]
+                ] = await self.bridge.json_request(LinkPlayCommand.META_INFO)  # type: ignore[assignment]
+            except LinkPlayInvalidDataException as exc:
+                if getattr(exc, "data", None) == "Failed":
+                    self.metainfo = {}
+                else:
+                    raise
+        else:
+            self.metainfo = {}
 
         # handle multiroom changes
         if self.bridge.device.controller is not None and (
@@ -277,6 +295,19 @@ class LinkPlayPlayer:
         ):
             await self.bridge.request(LinkPlayCommand.SEEK.format(position))
 
+    async def set_audio_output_hw_mode(self, mode: AudioOutputHwMode) -> None:
+        """Set the audio hardware output."""
+        await self.bridge.request(LinkPlayCommand.AUDIO_OUTPUT_HW_MODE_SET.format(mode))
+
+    async def get_audio_output_hw_mode(self) -> AudioOutputModeResponse:
+        """Get the audio hardware output."""
+        resp = await self.bridge.json_request(LinkPlayCommand.AUDIO_OUTPUT_HW_MODE)
+        return AudioOutputModeResponse(
+            AudioOutputHwMode(str(resp.get("hardware"))),
+            resp.get("source", "") == "1",
+            resp.get("audiocast", "") == "1",
+        )
+
     @property
     def muted(self) -> bool:
         """Returns if the player is muted."""
@@ -300,6 +331,13 @@ class LinkPlayPlayer:
         """Returns if the currently playing album."""
         return self.properties.get(PlayerAttribute.ALBUM, "")
 
+    @property
+    def album_art(self) -> str:
+        """Returns the url to the album art."""
+        return self.metainfo.get(MetaInfo.METADATA, {}).get(
+            MetaInfoMetaData.ALBUM_ART, ""
+        )
+
     @property
     def volume(self) -> int:
         """Returns the player volume, expressed in %."""
